import type { ActivityResponse, AnnouncementsResponse, AttendanceResponse, BadgesResponse, BehaviourResponse, ClassChartsResponse, DetentionsResponse, GetActivityOptions, GetAttendanceOptions, GetBehaviourOptions, GetFullActivityOptions, GetHomeworkOptions, GetLessonsOptions, GetStudentInfoResponse, HomeworksResponse, LessonsResponse, PupilFieldsResponse } from "../types.js";
/**
 * Shared client for both parent and student. This is not exported and should not be used directly
 */
export declare abstract class BaseClient {
    /**
     * Currently selected student ID
     */
    studentId: number;
    /**
     * Cookies used for authentication (set during login and can be empty)
     */
    authCookies: string[];
    /**
     * Session ID used for authentication
     */
    sessionId: string;
    /**
     * Last time the sessionId was updated
     */
    lastPing: number;
    /**
     * Base API URL, this is different depending on if its called as a parent or student
     */
    protected API_BASE: string;
    /**
     * Create a new client with the given API url
     * @param API_BASE Base API URL, this is different depending on if its called as a parent or student
     */
    constructor(API_BASE: string);
    abstract login(): Promise<void>;
    /**
     * Revalidates the session ID.
     *
     * This is called automatically when the session ID is older than 3 minutes and initially using the .login() method
     */
    getNewSessionId(): Promise<void>;
    /**
     * Makes a request to the ClassCharts API with the required authentication headers
     *
     * @param path Path to the API endpoint
     * @param fetchOptions Request Options
     * @param options
     * @param options.revalidateToken Whether to revalidate the session ID if it is older than 3 minutes
     *
     * @returns Response
     */
    makeAuthedRequest(path: string, fetchOptions: RequestInit, options?: {
        revalidateToken?: boolean;
    }): Promise<ClassChartsResponse<any, any>>;
    /**
     * Gets general information about the current student
     * @returns Student object
     */
    getStudentInfo(): Promise<GetStudentInfoResponse>;
    /**
     * Gets the current student's activity
     *
     * This function is only used for pagination, you likely want client.getFullActivity
     * @param options GetActivityOptions
     * @returns Activity data
     * @see getFullActivity
     */
    getActivity(options?: GetActivityOptions): Promise<ActivityResponse>;
    /**
     * Gets the current student's activity between two dates
     *
     * This function will automatically paginate through all the data returned by getActivity
     * @param options GetFullActivityOptions
     * @returns Activity Data
     * @see getActivity
     */
    getFullActivity(options: GetFullActivityOptions): Promise<ActivityResponse["data"]>;
    /**
     * Gets the current student's behaviour
     * @param options GetBehaviourOptions
     * @returns Array of behaviour points
     */
    getBehaviour(options?: GetBehaviourOptions): Promise<BehaviourResponse>;
    /**
     * Gets the current student's homework
     * @param options GetHomeworkOptions
     * @returns Array of homeworks
     */
    getHomeworks(options?: GetHomeworkOptions): Promise<HomeworksResponse>;
    /**
     * Gets the current student's lessons for a given date
     * @param options GetLessonsOptions
     * @returns Array of lessons
     */
    getLessons(options: GetLessonsOptions): Promise<LessonsResponse>;
    /**
     * Gets the current student's earned badges
     * @returns Array of badges
     */
    getBadges(): Promise<BadgesResponse>;
    /**
     * Gets the current student's announcements
     * @returns Array of announcements
     */
    getAnnouncements(): Promise<AnnouncementsResponse>;
    /**
     * Gets the current student's detentions
     * @returns Array of detentions
     */
    getDetentions(): Promise<DetentionsResponse>;
    /**
     * Gets the current student's attendance
     * @param options GetAttendanceOptions
     * @returns Array of dates of attendance
     */
    getAttendance(options?: GetAttendanceOptions): Promise<AttendanceResponse>;
    /**
     * Gets the current student's pupil fields
     * @returns Array of stats
     */
    getPupilFields(): Promise<PupilFieldsResponse>;
}
//# sourceMappingURL=baseClient.d.ts.map