"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParentClient = void 0;
const baseClient_js_1 = require("./baseClient.js");
const consts_js_1 = require("../utils/consts.js");
const utils_js_1 = require("../utils/utils.js");
/**
 * Parent Client.
 * See {@link BaseClient} for all shared methods.
 *
 * @example
 * ```ts
 * import { ParentClient } from "classcharts-api";
 * const client = new ParentClient("username", "password");
 * await client.login();
 * ```
 */
class ParentClient extends baseClient_js_1.BaseClient {
    /**
     * @param email Parent's email address
     * @param password Parent's password
     */
    constructor(email, password) {
        super(consts_js_1.API_BASE_PARENT);
        Object.defineProperty(this, "password", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "email", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        Object.defineProperty(this, "pupils", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.email = String(email);
        this.password = String(password);
        this.pupils = [];
    }
    /**
     * Authenticates with ClassCharts
     */
    async login() {
        if (!this.email) {
            throw new Error("Email not provided");
        }
        if (!this.password) {
            throw new Error("Password not provided");
        }
        const formData = new URLSearchParams();
        formData.append("_method", "POST");
        formData.append("email", this.email);
        formData.append("logintype", "existing");
        formData.append("password", this.password);
        formData.append("recaptcha-token", "no-token-available");
        const headers = new Headers({
            "Content-Type": "application/x-www-form-urlencoded",
        });
        const response = await fetch(`${consts_js_1.BASE_URL}/parent/login`, {
            method: "POST",
            body: formData,
            headers: headers,
            redirect: "manual",
        });
        if (response.status !== 302 || !response.headers.has("set-cookie")) {
            await response.body?.cancel(); // Make deno tests happy by closing the body, unsure whether this is needed for the actual library
            throw new Error("Unauthenticated: ClassCharts didn't return authentication cookies");
        }
        const cookies = String(response.headers.get("set-cookie"));
        // this.authCookies = cookies.split(";");
        const sessionCookies = (0, utils_js_1.parseCookies)(cookies);
        const sessionID = JSON.parse(String(sessionCookies.parent_session_credentials));
        this.sessionId = sessionID.session_id;
        this.pupils = await this.getPupils();
        if (!this.pupils) {
            throw new Error("Account has no pupils attached");
        }
        this.studentId = this.pupils[0].id;
    }
    /**
     * Get a list of pupils connected to this parent's account
     * @returns an array of Pupils connected to this parent's account
     */
    async getPupils() {
        const response = await this.makeAuthedRequest(`${this.API_BASE}/pupils`, {
            method: "GET",
        });
        return response.data;
    }
    /**
     * Selects a pupil to be used with API requests
     * @param pupilId Pupil ID obtained from this.pupils or getPupils()
     *
     * @see getPupils
     */
    selectPupil(pupilId) {
        if (!pupilId) {
            throw new Error("No pupil ID specified");
        }
        const pupils = this.pupils;
        for (let i = 0; i < pupils.length; i++) {
            const pupil = pupils[i];
            if (pupil.id === pupilId) {
                this.studentId = pupil.id;
                return;
            }
        }
        throw new Error("No pupil with specified ID returned");
    }
    /**
     * Changes the login password for the current parent account
     * @param currentPassword Current password
     * @param newPassword New password
     * @returns Whether the request was successful
     */
    async changePassword(currentPassword, newPassword) {
        const formData = new URLSearchParams();
        formData.append("current", currentPassword);
        formData.append("new", newPassword);
        formData.append("repeat", newPassword);
        return await this.makeAuthedRequest(`${this.API_BASE}/password`, {
            method: "POST",
            body: formData,
            headers: {
                "Content-Type": "application/x-www-form-urlencoded",
            },
        });
    }
}
exports.ParentClient = ParentClient;
