"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StudentClient = void 0;
const consts_js_1 = require("../utils/consts.js");
const baseClient_js_1 = require("./baseClient.js");
const utils_js_1 = require("../utils/utils.js");
/**
 * Student Client.
 * See {@link BaseClient} for all shared methods.
 *
 * @example
 * ```ts
 * import { StudentClient } from "classcharts-api";
 * // Date of birth MUST in the format DD/MM/YYYY
 * const client = new StudentClient("classchartsCode", "01/01/2000");
 * await client.login();
 * ```
 */
class StudentClient extends baseClient_js_1.BaseClient {
    /**
     * @param studentCode ClassCharts student code
     * @param dateOfBirth Student's date of birth
     */
    constructor(studentCode, dateOfBirth) {
        super(consts_js_1.API_BASE_STUDENT);
        /**
         * ClassCharts student code
         */
        Object.defineProperty(this, "studentCode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        /**
         * Student's date of birth
         */
        Object.defineProperty(this, "dateOfBirth", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: ""
        });
        this.studentCode = String(studentCode);
        this.dateOfBirth = String(dateOfBirth);
    }
    /**
     * Authenticates with ClassCharts
     */
    async login() {
        if (!this.studentCode) {
            throw new Error("Student Code not provided");
        }
        const formData = new URLSearchParams();
        formData.append("_method", "POST");
        formData.append("code", this.studentCode.toUpperCase());
        formData.append("dob", this.dateOfBirth);
        formData.append("remember_me", "1");
        formData.append("recaptcha-token", "no-token-available");
        const request = await fetch(`${consts_js_1.BASE_URL}/student/login`, {
            method: "POST",
            body: formData,
            redirect: "manual",
        });
        if (request.status !== 302 || !request.headers.has("set-cookie")) {
            await request.body?.cancel(); // Make deno tests happy by closing the body, unsure whether this is needed for the actual library
            throw new Error("Unauthenticated: ClassCharts didn't return authentication cookies");
        }
        const cookies = String(request.headers.get("set-cookie"));
        this.authCookies = cookies.split(",");
        const sessionCookies = (0, utils_js_1.parseCookies)(cookies);
        const sessionID = JSON.parse(String(sessionCookies.student_session_credentials));
        this.sessionId = sessionID.session_id;
        await this.getNewSessionId();
        const user = await this.getStudentInfo();
        this.studentId = user.data.user.id;
    }
    /**
     * Gets the available items in the current student's rewards shop
     * @returns Array of purchasable items
     */
    async getRewards() {
        return await this.makeAuthedRequest(`${this.API_BASE}/rewards/${this.studentId}`, {
            method: "GET",
        });
    }
    /**
     * Purchase a reward item from the current student's rewards shop
     * @param itemId number
     * @returns An object containing the current student's balance and item ID purchased
     */
    async purchaseReward(itemId) {
        return await this.makeAuthedRequest(`${this.API_BASE}/purchase/${itemId}`, {
            method: "POST",
            body: `pupil_id=${this.studentId}`,
        });
    }
    /**
     * Gets the current student's student code
     * @param options GetStudentCodeOptions
     * @param options.dateOfBirth Date of birth in the format YYYY-MM-DD
     * @returns
     */
    async getStudentCode(options) {
        const data = await this.makeAuthedRequest(`${this.API_BASE}/getcode`, {
            method: "POST",
            body: `date=${options.dateOfBirth}`,
            headers: {
                "content-type": "application/x-www-form-urlencoded",
            },
        });
        return data;
    }
}
exports.StudentClient = StudentClient;
